==> zxing_lib-0.7.0.tar.gz: lib/src/oned/rss/expanded/decoders/decoded_information.dart <==
/*
 * Copyright (C) 2010 ZXing authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * These authors would like to acknowledge the Spanish Ministry of Industry,
 * Tourism and Trade, for the support in the project TSI020301-2008-2
 * "PIRAmIDE: Personalizable Interactions with Resources on AmI-enabled
 * Mobile Dynamic Environments", led by Treelogic
 * ( http://www.treelogic.com/ ):
 *
 *   http://www.piramidepse.com/
 */

import 'decoded_object.dart';

/// @author Pablo Orduña, University of Deusto (pablo.orduna@deusto.es)
/// @author Eduardo Castillejo, University of Deusto (eduardo.castillejo@deusto.es)
class DecodedInformation extends DecodedObject {
  final String _newString;
  final int _remainingValue;
  final bool _remaining;

  DecodedInformation(int newPosition, this._newString,
      [this._remainingValue = 0])
      : _remaining = _remainingValue > 0,
        super(newPosition);

  String get newString => _newString;

  bool get isRemaining => _remaining;

  int get remainingValue => _remainingValue;
}

==> zxing_lib-1.1.1.tar.gz: lib/src/oned/rss/expanded/decoders/decoded_information.dart <==
/*
 * Copyright (C) 2010 ZXing authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * These authors would like to acknowledge the Spanish Ministry of Industry,
 * Tourism and Trade, for the support in the project TSI020301-2008-2
 * "PIRAmIDE: Personalizable Interactions with Resources on AmI-enabled
 * Mobile Dynamic Environments", led by Treelogic
 * ( http://www.treelogic.com/ ):
 *
 *   http://www.piramidepse.com/
 */

import 'decoded_object.dart';

/// @author Pablo Orduña, University of Deusto (pablo.orduna@deusto.es)
/// @author Eduardo Castillejo, University of Deusto (eduardo.castillejo@deusto.es)
class DecodedInformation extends DecodedObject {
  final String _newString;
  final int _remainingValue;
  final bool _remaining;

  DecodedInformation(
    int newPosition,
    this._newString, [
    this._remainingValue = 0,
  ])  : _remaining = _remainingValue > 0,
        super(newPosition);

  String get newString => _newString;

  bool get isRemaining => _remaining;

  int get remainingValue => _remainingValue;
}
